From: Dhruv Chawla <[email protected]>
Signed-off-by: Dhruv Chawla <[email protected]>
gcc/ChangeLog:
* adjust-alignment.cc (pass_adjust_alignment::execute): Fix typos.
* alias.cc (alias_set_subset_of): Likewise.
(alias_ptr_types_compatible_p): Likewise.
(get_alias_set): Likewise.
(record_component_aliases): Likewise.
(base_alias_check): Likewise.
* alloc-pool.h: Likewise.
* asan.cc (insert_if_then_before_iter): Likewise.
(asan_expand_check_ifn): Likewise.
(hwasan_expand_check_ifn): Likewise.
* asan.h (sanitize_flags_p): Likewise.
* asm-toplevel.cc (analyze_toplevel_extended_asm): Likewise.
* attr-fnspec.h: Likewise.
* attribs.cc (decl_attributes): Likewise.
* auto-profile.cc (function_instance::match): Likewise.
(function_instance::remove_icall_target): Likewise.
(autofdo_source_profile::offline_external_functions): Likewise.
(afdo_set_bb_count): Likewise.
(scale_bbs): Likewise.
(afdo_adjust_guessed_profile): Likewise.
* basic-block.h (find_fallthru_edge): Likewise.
* bbitmap.h: Likewise.
* bitmap.cc (bitmap_list_find_element): Likewise.
* bitmap.h: Likewise.
* btfout.cc (BTF_INFO_SECTION_FLAGS): Likewise.
(btf_asm_type): Likewise.
(output_btf_vars): Likewise.
(btf_add_used_type_1): Likewise.
* builtins.cc (string_length): Likewise.
(expand_builtin_setjmp_setup): Likewise.
(inline_expand_builtin_bytecmp): Likewise.
* builtins.def: Likewise.
* ccmp.cc (get_compare_parts): Likewise.
(expand_ccmp_next): Likewise.
* ccmp.h: Likewise.
* cfg.cc (update_bb_profile_for_threading): Likewise.
* cfganal.cc (post_order_compute): Likewise.
* cfgbuild.cc (find_many_sub_basic_blocks): Likewise.
* cfgexpand.cc (vars_ssa_cache::dump): Likewise.
(add_scope_conflicts_1): Likewise.
(set_parm_rtl): Likewise.
(expand_one_ssa_partition): Likewise.
(expand_one_var): Likewise.
(discover_nonconstant_array_refs_r): Likewise.
(pass_expand::execute): Likewise.
* cfgloop.cc (get_estimated_loop_iterations): Likewise.
* cfgloopanal.cc (loop_count_in): Likewise.
* cfgloopmanip.cc (loop_exit_for_scaling): Likewise.
(update_loop_exit_probability_scale_dom_bbs): Likewise.
* cgraph.cc (add_detected_attribute_1): Likewise.
(cgraph_edge::maybe_hot_p): Likewise.
* cgraph.h (struct cgraph_node): Likewise.
* cif-code.def (ORIGINALLY_INDIRECT_CALL): Likewise.
* collect2.cc (main): Likewise.
* combine.cc (distribute_notes): Likewise.
* configure.ac: Likewise.
* coretypes.h (enum pad_direction): Likewise.
* coroutine-passes.cc (make_pass_coroutine_lower_builtins): Likewise.
* coverage.cc (coverage_compute_profile_id): Likewise.
* cse.cc (struct set): Likewise.
(try_back_substitute_reg): Likewise.
(count_stores): Likewise.
* cselib.cc (struct cselib_hasher): Likewise.
* ctfc.cc (ctfc_get_num_ctf_vars): Likewise.
(ctf_add_string): Likewise.
(ctf_add_function_arg): Likewise.
* ctfc.h (GTY): Likewise.
(CTF_AUX_STRTAB): Likewise.
(ctfc_get_num_ctf_vars): Likewise.
* ctfout.cc (ctf_asm_sou_lmember): Likewise.
(output_ctf_header): Likewise.
* debug.h: Likewise.
* defaults.h: Likewise.
* df-problems.cc (df_simulate_fixup_sets): Likewise.
(df_simulate_finalize_backwards): Likewise.
* diagnostic-context-rich-location.cc
(lazy_diagnostic_context_path::make_inner_path): Likewise.
* diagnostics/color.cc (auto_enable_urls): Likewise.
* diagnostics/context.h: Likewise.
* diagnostics/sarif-sink.cc (get_message_from_result): Likewise.
* double-int.cc (double_int::lrotate): Likewise.
* dwarf2asm.cc (dw2_asm_output_delta_uleb128): Likewise.
* dwarf2cfi.cc (dwarf2out_frame_debug_expr): Likewise.
* dwarf2ctf.cc (ctf_get_AT_data_member_location): Likewise.
(handle_ctf_type_tags): Likewise.
* dwarf2out.cc (cst_pool_loc_descr): Likewise.
(loc_list_for_address_of_addr_expr_of_indirect_ref): Likewise.
(resolve_args_picking_1): Likewise.
(typed_binop_from_tree): Likewise.
(gen_array_type_die): Likewise.
* dwarf2out.h (struct dw_val_node): Likewise.
(dw_loc_dtprel): Likewise.
---
gcc/adjust-alignment.cc | 2 +-
gcc/alias.cc | 10 +++++-----
gcc/alloc-pool.h | 2 +-
gcc/asan.cc | 6 +++---
gcc/asan.h | 2 +-
gcc/asm-toplevel.cc | 2 +-
gcc/attr-fnspec.h | 2 +-
gcc/attribs.cc | 2 +-
gcc/auto-profile.cc | 16 ++++++++--------
gcc/basic-block.h | 2 +-
gcc/bbitmap.h | 2 +-
gcc/bitmap.cc | 4 ++--
gcc/bitmap.h | 4 ++--
gcc/btfout.cc | 8 ++++----
gcc/builtins.cc | 6 +++---
gcc/builtins.def | 4 ++--
gcc/ccmp.cc | 4 ++--
gcc/ccmp.h | 2 +-
gcc/cfg.cc | 2 +-
gcc/cfganal.cc | 4 ++--
gcc/cfgbuild.cc | 2 +-
gcc/cfgexpand.cc | 16 ++++++++--------
gcc/cfgloop.cc | 2 +-
gcc/cfgloopanal.cc | 2 +-
gcc/cfgloopmanip.cc | 10 +++++-----
gcc/cgraph.cc | 4 ++--
gcc/cgraph.h | 10 +++++-----
gcc/cif-code.def | 2 +-
gcc/collect2.cc | 6 +++---
gcc/combine.cc | 2 +-
gcc/configure.ac | 4 ++--
gcc/coretypes.h | 4 ++--
gcc/coroutine-passes.cc | 2 +-
gcc/coverage.cc | 2 +-
gcc/cse.cc | 6 +++---
gcc/cselib.cc | 2 +-
gcc/ctfc.cc | 8 ++++----
gcc/ctfc.h | 6 +++---
gcc/ctfout.cc | 4 ++--
gcc/debug.h | 2 +-
gcc/defaults.h | 2 +-
gcc/df-problems.cc | 4 ++--
gcc/diagnostic-context-rich-location.cc | 4 ++--
gcc/diagnostics/color.cc | 2 +-
gcc/diagnostics/context.h | 2 +-
gcc/diagnostics/sarif-sink.cc | 2 +-
gcc/double-int.cc | 2 +-
gcc/dwarf2asm.cc | 2 +-
gcc/dwarf2cfi.cc | 2 +-
gcc/dwarf2ctf.cc | 6 +++---
gcc/dwarf2out.cc | 10 +++++-----
gcc/dwarf2out.h | 4 ++--
52 files changed, 112 insertions(+), 112 deletions(-)
diff --git a/gcc/adjust-alignment.cc b/gcc/adjust-alignment.cc
index 3ce77bb5a8f..8d2b2478793 100644
--- a/gcc/adjust-alignment.cc
+++ b/gcc/adjust-alignment.cc
@@ -64,7 +64,7 @@ pass_adjust_alignment::execute (function *fun)
FOR_EACH_LOCAL_DECL (fun, i, var)
{
- /* Don't adjust aligment for static local var and hard register var. */
+ /* Don't adjust alignment for static local var and hard register var. */
if (is_global_var (var) || DECL_HARD_REGISTER (var))
continue;
diff --git a/gcc/alias.cc b/gcc/alias.cc
index 6e16b21327f..92c9d8bc360 100644
--- a/gcc/alias.cc
+++ b/gcc/alias.cc
@@ -464,7 +464,7 @@ alias_set_subset_of (alias_set_type set1, alias_set_type
set2)
them subset of each other. */
if (set1 == voidptr_set || set2 == voidptr_set)
return true;
- /* If SET2 contains universal pointer's alias set, then we consdier
+ /* If SET2 contains universal pointer's alias set, then we consider
every (non-universal) pointer. */
if (ase2->children && set1 != voidptr_set
&& ase2->children->get (voidptr_set))
@@ -850,7 +850,7 @@ alias_ptr_types_compatible_p (tree t1, tree t2)
== TYPE_MAIN_VARIANT (TREE_TYPE (t2)));
}
-/* Create emptry alias set entry. */
+/* Create empty alias set entry. */
alias_set_entry *
init_alias_set_entry (alias_set_type set)
@@ -1115,7 +1115,7 @@ get_alias_set (tree t)
/* Assign the alias set to both p and t.
We cannot call get_alias_set (p) here as that would trigger
infinite recursion when p == t. In other cases it would just
- trigger unnecesary legwork of rebuilding the pointer again. */
+ trigger unnecessary legwork of rebuilding the pointer again. */
gcc_checking_assert (p == TYPE_MAIN_VARIANT (p));
if (TYPE_ALIAS_SET_KNOWN_P (p))
set = TYPE_ALIAS_SET (p);
@@ -1308,7 +1308,7 @@ record_component_aliases (tree type, alias_set_type
superset)
alias_set_type set = get_alias_set (t);
record_alias_subset (superset, set);
/* If the field has alias-set zero make sure to still record
- any componets of it. This makes sure that for
+ any components of it. This makes sure that for
struct A {
struct B {
int i;
@@ -2243,7 +2243,7 @@ base_alias_check (rtx x, rtx x_base, rtx y, rtx y_base,
alias one another, though "char a; long b;" cannot. AND addresses may
implicitly alias surrounding objects; i.e. unaligned access in DImode
via AND address can alias all surrounding object types except those
- with aligment 8 or higher. */
+ with alignment 8 or higher. */
if (GET_CODE (x) == AND && GET_CODE (y) == AND)
return true;
if (GET_CODE (x) == AND
diff --git a/gcc/alloc-pool.h b/gcc/alloc-pool.h
index 2a54cdacf10..f81c1794137 100644
--- a/gcc/alloc-pool.h
+++ b/gcc/alloc-pool.h
@@ -37,7 +37,7 @@ extern ALLOC_POOL_ID_TYPE last_id;
class pool_usage: public mem_usage
{
public:
- /* Default contructor. */
+ /* Default constructor. */
pool_usage (): m_element_size (0), m_pool_name ("") {}
/* Constructor. */
pool_usage (size_t allocated, size_t times, size_t peak,
diff --git a/gcc/asan.cc b/gcc/asan.cc
index d91650200ff..260bf79dc84 100644
--- a/gcc/asan.cc
+++ b/gcc/asan.cc
@@ -2696,7 +2696,7 @@ insert_if_then_before_iter (gcond *cond,
}
/* Build (base_addr >> ASAN_SHADOW_SHIFT) + asan_shadow_offset ().
- If RETURN_ADDRESS is set to true, return memory location instread
+ If RETURN_ADDRESS is set to true, return memory location instead
of a value in the shadow memory. */
static tree
@@ -4121,7 +4121,7 @@ asan_expand_check_ifn (gimple_stmt_iterator *iter, bool
use_calls)
{
//asan instrumentation code goes here.
}
- // falltrough instructions, starting with *ITER. */
+ // fallthrough instructions, starting with *ITER. */
g = gimple_build_cond (NE_EXPR,
len,
@@ -4983,7 +4983,7 @@ hwasan_expand_check_ifn (gimple_stmt_iterator *iter, bool)
{
// hwasan instrumentation code goes here.
}
- // falltrough instructions, starting with *ITER. */
+ // fallthrough instructions, starting with *ITER. */
g = gimple_build_cond (NE_EXPR,
len,
diff --git a/gcc/asan.h b/gcc/asan.h
index af34954b4b7..aa31f491663 100644
--- a/gcc/asan.h
+++ b/gcc/asan.h
@@ -267,7 +267,7 @@ sanitize_flags_p (sanitize_code_type flag,
return result_flags;
}
-/* Return true when coverage sanitization should happend for FN function. */
+/* Return true when coverage sanitization should happen for FN function. */
inline bool
sanitize_coverage_p (const_tree fn = current_function_decl)
diff --git a/gcc/asm-toplevel.cc b/gcc/asm-toplevel.cc
index 8742b7fc6a2..c58ca48fcae 100644
--- a/gcc/asm-toplevel.cc
+++ b/gcc/asm-toplevel.cc
@@ -120,7 +120,7 @@ analyze_toplevel_extended_asm ()
/* Checks all toplevel assembly contents and compares them with known symbols.
Marks those symbols with relevant flags.
- Heuristics: Detects anything in assembly that looks like an identifer.
+ Heuristics: Detects anything in assembly that looks like an identifier.
This pass must be in WPA, otherwise we will not see all possibly referenced
symbols - if a symbol is only declared, it will not be in the callgraph if
diff --git a/gcc/attr-fnspec.h b/gcc/attr-fnspec.h
index 45248ea8edd..f02016f0004 100644
--- a/gcc/attr-fnspec.h
+++ b/gcc/attr-fnspec.h
@@ -186,7 +186,7 @@ public:
}
/* Return true if the pointed-to type of the argument correspond to the
- size of the memory acccess. */
+ size of the memory access. */
bool
arg_access_size_given_by_type_p (unsigned int i) const
{
diff --git a/gcc/attribs.cc b/gcc/attribs.cc
index 99f2fd75531..cd4be1bd6c5 100644
--- a/gcc/attribs.cc
+++ b/gcc/attribs.cc
@@ -853,7 +853,7 @@ decl_attributes (tree *node, tree attributes, int flags,
bool no_add_attrs = false;
/* Check for exclusions with other attributes on the current
- declation as well as the last declaration of the same
+ declaration as well as the last declaration of the same
symbol already processed (if one exists). Detect and
reject incompatible attributes. */
bool built_in = flags & ATTR_FLAG_BUILT_IN;
diff --git a/gcc/auto-profile.cc b/gcc/auto-profile.cc
index f4562d7f2f9..6aa5166c748 100644
--- a/gcc/auto-profile.cc
+++ b/gcc/auto-profile.cc
@@ -1713,7 +1713,7 @@ function_instance::match (cgraph_node *node,
fprintf (dump_file, "\n");
}
basic_block bb;
- /* Sets used to track if entires in auto-profile are useful. */
+ /* Sets used to track if entries in auto-profile are useful. */
hash_set<const count_info *> counts;
hash_set<const count_info *> targets;
hash_set<const function_instance *> functions;
@@ -1756,7 +1756,7 @@ function_instance::match (cgraph_node *node,
inline_stack stack;
/* We do not assign discriminators to PHI nodes.
- In case we every start using them, we wil need to
+ In case we every start using them, we will need to
update tree-cfg.cc::assign_discriminators. */
gcc_assert (gimple_location (phi) == UNKNOWN_LOCATION);
get_inline_stack_in_node (gimple_location (phi), &stack, node);
@@ -2359,7 +2359,7 @@ function_instance::remove_icall_target (tree fn, gcall
*stmt)
n++;
}
/* TODO: If we add support for multiple targets, we may want to
- remove only those we succesfully inlined. */
+ remove only those we successfully inlined. */
gcc_assert (n);
}
@@ -2389,7 +2389,7 @@ autofdo_source_profile::offline_external_functions ()
{
/* Watch for duplicate entries.
This seems to happen in practice and may be useful to distinguish
- multiple static symbols of the same name, but we do not realy
+ multiple static symbols of the same name, but we do not really
have a way to differentiate them in get_symbol_name lookup. */
int index = afdo_string_table->get_index (n1);
if (index != (int)i)
@@ -2517,7 +2517,7 @@ autofdo_source_profile::offline_external_functions ()
= afdo_string_table->get_cgraph_node (last_name);
if (dump_file)
fprintf (dump_file, "New name %s %s\n", name,
- n ? "wth corresponding definition"
+ n ? "with corresponding definition"
: "with no corresponding definition");
if (n)
seen.add (last_name);
@@ -3563,7 +3563,7 @@ afdo_set_bb_count (basic_block bb, hash_set <basic_block>
&zero_bbs)
3. BB1 and BB2 are in the same loop nest.
This function finds the equivalent class for each basic block, and
stores a pointer to the first BB in its equivalent class. Meanwhile,
- set bb counts for the same equivalent class to be idenical. Update
+ set bb counts for the same equivalent class to be identical. Update
ANNOTATED_BB for the first BB in its equivalent class. */
static void
@@ -3978,7 +3978,7 @@ scale_bbs (const vec <basic_block> &bbs, sreal scale)
b->count = b->count.force_guessed () * scale;
/* If we scaled to 0, make it auto-fdo since that is treated
- less agressively. */
+ less aggressively. */
if (!b->count.nonzero_p () && o.nonzero_p ())
b->count = profile_count::zero ().afdo ();
if (dump_file)
@@ -4208,7 +4208,7 @@ afdo_adjust_guessed_profile (bb_set *annotated_bb)
boundary = true;
annotated_count += AFDO_EINFO (e)->get_count ();
}
- /* If source is anotated, combine with static
+ /* If source is annotated, combine with static
probability prediction.
TODO: We can do better in case some of edges out are
annotated and distribute only remaining count out of BB. */
diff --git a/gcc/basic-block.h b/gcc/basic-block.h
index 0df7f5c4c92..08082447568 100644
--- a/gcc/basic-block.h
+++ b/gcc/basic-block.h
@@ -550,7 +550,7 @@ find_fallthru_edge (vec<edge, va_gc> *edges)
return e;
}
-/* Check tha probability is sane. */
+/* Check that probability is sane. */
inline void
check_probability (int prob)
diff --git a/gcc/bbitmap.h b/gcc/bbitmap.h
index e8da6cf5937..508392d4c8c 100644
--- a/gcc/bbitmap.h
+++ b/gcc/bbitmap.h
@@ -28,7 +28,7 @@ along with GCC; see the file COPYING3. If not see
Sets are stored as a fixed length array of uint64_t elements. The length of
this array is given as a template parameter. */
-/* Use recusive templated functions to define constexpr operations. */
+/* Use recursive templated functions to define constexpr operations. */
template<int M>
struct bbitmap_operators
{
diff --git a/gcc/bitmap.cc b/gcc/bitmap.cc
index 4ba78e8bf90..8f232dde7aa 100644
--- a/gcc/bitmap.cc
+++ b/gcc/bitmap.cc
@@ -414,14 +414,14 @@ bitmap_list_find_element (bitmap head, unsigned int indx)
/* Splay-tree view of bitmaps.
- This is an almost one-to-one the implementatin of the simple top-down
+ This is an almost one-to-one the implementation of the simple top-down
splay tree in Sleator and Tarjan's "Self-adjusting Binary Search Trees".
It is probably not the most efficient form of splay trees, but it should
be good enough to experiment with this idea of bitmaps-as-trees.
For all functions below, the variable or function argument "t" is a node
in the tree, and "e" is a temporary or new node in the tree. The rest
- is sufficiently straigh-forward (and very well explained in the paper)
+ is sufficiently straight-forward (and very well explained in the paper)
that comment would only clutter things. */
static inline void
diff --git a/gcc/bitmap.h b/gcc/bitmap.h
index 3bdfed52a16..35f0bd060c1 100644
--- a/gcc/bitmap.h
+++ b/gcc/bitmap.h
@@ -64,7 +64,7 @@ along with GCC; see the file COPYING3. If not see
For random-access sparse sets of unknown universe, the binary tree
representation is likely to be a more suitable choice. Theoretical
access times for the binary tree representation are better than those
- for the linked-list, but in practice this is only true for truely
+ for the linked-list, but in practice this is only true for truly
random access.
Often the most suitable representation during construction of the set
@@ -218,7 +218,7 @@ along with GCC; see the file COPYING3. If not see
class bitmap_usage: public mem_usage
{
public:
- /* Default contructor. */
+ /* Default constructor. */
bitmap_usage (): m_nsearches (0), m_search_iter (0) {}
/* Constructor. */
bitmap_usage (size_t allocated, size_t times, size_t peak,
diff --git a/gcc/builtins.cc b/gcc/builtins.cc
index 72310f1c928..cbc9bcd0e05 100644
--- a/gcc/builtins.cc
+++ b/gcc/builtins.cc
@@ -569,7 +569,7 @@ string_length (const void *ptr, unsigned eltsize, unsigned
maxelts)
than what a C strlen call would return.
ELTSIZE is 1 for normal single byte character strings, and 2 or
- 4 for wide characer strings. ELTSIZE is by default 1.
+ 4 for wide character strings. ELTSIZE is by default 1.
The value returned is of type `ssizetype'. */
@@ -928,7 +928,7 @@ expand_builtin_setjmp_setup (rtx buf_addr, rtx
receiver_label)
/* Construct the trailing part of a __builtin_setjmp call. This is
also called directly by the SJLJ exception handling code.
- If RECEIVER_LABEL is NULL, instead contruct a nonlocal goto handler. */
+ If RECEIVER_LABEL is NULL, instead construct a nonlocal goto handler. */
void
expand_builtin_setjmp_receiver (rtx receiver_label)
@@ -7662,7 +7662,7 @@ inline_expand_builtin_bytecmp (tree exp, rtx target)
|| fcode == BUILT_IN_STRNCMP
|| fcode == BUILT_IN_MEMCMP);
- /* On a target where the type of the call (int) has same or narrower
presicion
+ /* On a target where the type of the call (int) has same or narrower
precision
than unsigned char, give up the inlining expansion. */
if (TYPE_PRECISION (unsigned_char_type_node)
>= TYPE_PRECISION (TREE_TYPE (exp)))
diff --git a/gcc/builtins.def b/gcc/builtins.def
index 785c1c99c3f..ce9f29d419c 100644
--- a/gcc/builtins.def
+++ b/gcc/builtins.def
@@ -218,7 +218,7 @@ along with GCC; see the file COPYING3. If not see
false, true, true, ATTRS, false, \
flag_openacc)
/* Set NONANSI_P = false to enable the builtins also with
-fno-nonansi-builtins,
- esp. as -std=c++../c.. imply that flag and -fopenacc should be othogonal.
*/
+ esp. as -std=c++../c.. imply that flag and -fopenacc should be orthogonal.
*/
#undef DEF_GOACC_BUILTIN_COMPILER
#define DEF_GOACC_BUILTIN_COMPILER(ENUM, NAME, TYPE, ATTRS) \
DEF_BUILTIN (ENUM, "__builtin_" NAME, BUILT_IN_NORMAL, TYPE, TYPE, \
@@ -235,7 +235,7 @@ along with GCC; see the file COPYING3. If not see
|| flag_openmp \
|| flag_tree_parallelize_loops > 1))
/* Set NONANSI_P = false to enable the builtins also with
-fno-nonansi-builtins,
- esp. as -std=c++../c.. imply that flag and -fopenmp should be othogonal. */
+ esp. as -std=c++../c.. imply that flag and -fopenmp should be orthogonal.
*/
#undef DEF_GOMP_BUILTIN_COMPILER
#define DEF_GOMP_BUILTIN_COMPILER(ENUM, NAME, TYPE, ATTRS) \
DEF_BUILTIN (ENUM, "__builtin_" NAME, BUILT_IN_NORMAL, TYPE, TYPE, \
diff --git a/gcc/ccmp.cc b/gcc/ccmp.cc
index 847a221158a..0564ccf34bf 100644
--- a/gcc/ccmp.cc
+++ b/gcc/ccmp.cc
@@ -159,7 +159,7 @@ get_compare_parts (tree t, rtx_code *rcode,
result of the previous CMP or CCMP. The function expands the
next compare based on G which is ANDed/ORed with the previous
compare depending on CODE.
- PREP_SEQ returns all insns to prepare opearands for compare.
+ PREP_SEQ returns all insns to prepare operands for compare.
GEN_SEQ returns all compare insns. */
static rtx
expand_ccmp_next (tree op, tree_code code, rtx prev,
@@ -182,7 +182,7 @@ expand_ccmp_next (tree op, tree_code code, rtx prev,
hook gen_ccmp_first is used to expand the first compare.
hook gen_ccmp_next is used to expand the following CCMP.
- PREP_SEQ returns all insns to prepare opearand.
+ PREP_SEQ returns all insns to prepare operand.
GEN_SEQ returns all compare insns. */
static rtx
expand_ccmp_expr_1 (gimple *g, rtx_insn **prep_seq, rtx_insn **gen_seq)
diff --git a/gcc/ccmp.h b/gcc/ccmp.h
index 073bc3beec0..d9c8a349e01 100644
--- a/gcc/ccmp.h
+++ b/gcc/ccmp.h
@@ -1,4 +1,4 @@
-/* Conditional comapre related functions.
+/* Conditional compare related functions.
Copyright (C) 2014-2026 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/cfg.cc b/gcc/cfg.cc
index 6b9d5b24a55..8a253fed1d1 100644
--- a/gcc/cfg.cc
+++ b/gcc/cfg.cc
@@ -977,7 +977,7 @@ update_bb_profile_for_threading (basic_block bb,
gcc_assert (bb == taken_edge->src);
/* If there is no profile or the threaded path is never executed
- we don't need to upate. */
+ we don't need to update. */
if (!bb->count.initialized_p ()
|| count == profile_count::zero ())
return;
diff --git a/gcc/cfganal.cc b/gcc/cfganal.cc
index 7d6ac03afd6..dedd9b648c5 100644
--- a/gcc/cfganal.cc
+++ b/gcc/cfganal.cc
@@ -742,7 +742,7 @@ post_order_compute (int *post_order, bool
include_entry_exit,
/* Helper routine for inverted_rev_post_order_compute
flow_dfs_compute_reverse_execute, and the reverse-CFG
- deapth first search in dominance.cc.
+ depth first search in dominance.cc.
BB has to belong to a region of CFG
unreachable by inverted traversal from the exit.
i.e. there's no control flow path from ENTRY to EXIT
@@ -1304,7 +1304,7 @@ ret_from_find_loops:
dest_scc = bb_data[dest_scc].scc;
if (src_scc == dest_scc)
continue;
- /* When dest_scc is nested insde src_scc it's not an
+ /* When dest_scc is nested inside src_scc it's not an
exit. */
int tem_dest_scc = dest_scc;
unsigned dest_scc_depth = 0;
diff --git a/gcc/cfgbuild.cc b/gcc/cfgbuild.cc
index 18a32902285..3ed1eca694b 100644
--- a/gcc/cfgbuild.cc
+++ b/gcc/cfgbuild.cc
@@ -791,7 +791,7 @@ find_many_sub_basic_blocks (sbitmap blocks)
/* If nothing changed, there is no need to create new BBs. */
if (EDGE_COUNT (bb->succs) == n_succs[bb->index])
{
- /* In rare occassions RTL expansion might have mistakely assigned
+ /* In rare occasions RTL expansion might have mistakely assigned
a probabilities different from what is in CFG. This happens
when we try to split branch to two but optimize out the
second branch during the way. See PR81030. */
diff --git a/gcc/cfgexpand.cc b/gcc/cfgexpand.cc
index 7517e8d5788..c466ae16801 100644
--- a/gcc/cfgexpand.cc
+++ b/gcc/cfgexpand.cc
@@ -722,7 +722,7 @@ vars_ssa_cache::dump (FILE *file)
/* Returns the filled in cache for NAME.
This will fill in the cache if it does not exist already.
Returns an empty for ssa names that can't contain pointers
- (only intergal types and pointer types will contain pointers). */
+ (only integral types and pointer types will contain pointers). */
const_bitmap
vars_ssa_cache::operator() (tree name)
@@ -900,7 +900,7 @@ add_scope_conflicts_1 (vars_ssa_cache &cache, basic_block
bb, bitmap work, bool
{
/* When we are inheriting live variables from our predecessors
through a CFG merge we might not see an actual mention of
- the variables to record the approprate conflict as defs/uses
+ the variables to record the appropriate conflict as defs/uses
might be through indirect stores/loads. For this reason
we have to make sure each live variable conflicts with
each other. When there's just a single predecessor the
@@ -1697,7 +1697,7 @@ set_parm_rtl (tree parm, rtx x)
TYPE_MODE (TREE_TYPE (parm)),
TYPE_ALIGN (TREE_TYPE (parm)));
- /* If the variable alignment is very large we'll dynamicaly
+ /* If the variable alignment is very large we'll dynamically
allocate it, which means that in-frame portion is just a
pointer. ??? We've got a pseudo for sure here, do we
actually dynamically allocate its spilling area if needed?
@@ -1847,7 +1847,7 @@ expand_one_ssa_partition (tree var)
TYPE_MODE (TREE_TYPE (var)),
TYPE_ALIGN (TREE_TYPE (var)));
- /* If the variable alignment is very large we'll dynamicaly allocate
+ /* If the variable alignment is very large we'll dynamically allocate
it, which means that in-frame portion is just a pointer. */
if (align > MAX_SUPPORTED_STACK_ALIGNMENT)
align = GET_MODE_ALIGNMENT (Pmode);
@@ -2075,7 +2075,7 @@ expand_one_var (tree var, bool toplevel, bool
really_expand,
else
align = MINIMUM_ALIGNMENT (var, DECL_MODE (var), DECL_ALIGN (var));
- /* If the variable alignment is very large we'll dynamicaly allocate
+ /* If the variable alignment is very large we'll dynamically allocate
it, which means that in-frame portion is just a pointer. */
if (align > MAX_SUPPORTED_STACK_ALIGNMENT)
align = GET_MODE_ALIGNMENT (Pmode);
@@ -6748,7 +6748,7 @@ discover_nonconstant_array_refs_r (tree * tp, int
*walk_subtrees,
/* References of size POLY_INT_CST to a fixed-size object must go
through memory. It's more efficient to force that here than
to create temporary slots on the fly.
- RTL expansion expectes TARGET_MEM_REF to always address actual memory.
+ RTL expansion expects TARGET_MEM_REF to always address actual memory.
Also, force to stack non-BLKmode vars accessed through VIEW_CONVERT_EXPR
to BLKmode type. */
else if (TREE_CODE (t) == TARGET_MEM_REF
@@ -7084,8 +7084,8 @@ pass_expand::execute (function *fun)
crtl->init_stack_alignment ();
fun->cfg->max_jumptable_ents = 0;
- /* Resovle the function section. Some targets, like ARM EABI rely on
knowledge
- of the function section at exapnsion time to predict distance of calls.
*/
+ /* Resolve the function section. Some targets, like ARM EABI rely on
knowledge
+ of the function section at expansion time to predict distance of calls.
*/
resolve_unique_section (current_function_decl, 0, flag_function_sections);
/* Expand the variables recorded during gimple lowering. */
diff --git a/gcc/cfgloop.cc b/gcc/cfgloop.cc
index 70f2996a416..ee4ff4a158e 100644
--- a/gcc/cfgloop.cc
+++ b/gcc/cfgloop.cc
@@ -2008,7 +2008,7 @@ likely_max_stmt_executions_int (class loop *loop)
bool
get_estimated_loop_iterations (class loop *loop, widest_int *nit)
{
- /* Even if the bound is not recorded, possibly we can derrive one from
+ /* Even if the bound is not recorded, possibly we can derive one from
profile. */
if (!loop->any_estimate)
{
diff --git a/gcc/cfgloopanal.cc b/gcc/cfgloopanal.cc
index b833c7a465f..a72a443fde6 100644
--- a/gcc/cfgloopanal.cc
+++ b/gcc/cfgloopanal.cc
@@ -265,7 +265,7 @@ loop_count_in (const class loop *loop)
entry of the loop. If this is the case initialize RET with the number
of iterations.
- RELIABLE is set if profile indiates that the returned value should be
+ RELIABLE is set if profile indicates that the returned value should be
realistic estimate. (This is the case if we read profile and did not
messed it up yet and not the case of guessed profiles.)
diff --git a/gcc/cfgloopmanip.cc b/gcc/cfgloopmanip.cc
index dd5ae82f73e..f7551d5f30d 100644
--- a/gcc/cfgloopmanip.cc
+++ b/gcc/cfgloopmanip.cc
@@ -559,7 +559,7 @@ loop_exit_for_scaling (class loop *loop)
If DESIRED_COUNT is NULL, loop entry count will be used.
In consistent profile usually loop exists as many times as it is entred.
- Return updated exit if successfull and NULL otherwise. */
+ Return updated exit if successful and NULL otherwise. */
edge
update_loop_exit_probability_scale_dom_bbs (class loop *loop,
@@ -619,7 +619,7 @@ update_loop_exit_probability_scale_dom_bbs (class loop
*loop,
If B2 count is smaller than desired exit edge count
the profile was inconsistent with the newly discovered upper bound.
- Probablity of edge B1->B2 is too low. We do not attempt to fix
+ Probability of edge B1->B2 is too low. We do not attempt to fix
that (as it is hard in general). */
if (desired_count > exit_edge->src->count
&& exit_edge->src->count.differs_from_p (desired_count))
@@ -630,7 +630,7 @@ update_loop_exit_probability_scale_dom_bbs (class loop
*loop,
loop->num);
exit_edge->src->count.dump (dump_file, cfun);
fprintf (dump_file,
- " which is smaller then desired count of exitting loop ");
+ " which is smaller then desired count of exiting loop ");
desired_count.dump (dump_file, cfun);
fprintf (dump_file, ". Profile update is impossible.\n");
}
@@ -689,9 +689,9 @@ update_loop_exit_probability_scale_dom_bbs (class loop
*loop,
/* Scale profile in LOOP by P.
If ITERATION_BOUND is not -1, scale even further if loop is predicted
to iterate too many times.
- Before caling this function, preheader block profile should be already
+ Before calling this function, preheader block profile should be already
scaled to final count. This is necessary because loop iterations are
- determined by comparing header edge count to latch ege count and thus
+ determined by comparing header edge count to latch edge count and thus
they need to be scaled synchronously. */
void
diff --git a/gcc/cgraph.cc b/gcc/cgraph.cc
index 353e8b498aa..13ea9c34629 100644
--- a/gcc/cgraph.cc
+++ b/gcc/cgraph.cc
@@ -3083,7 +3083,7 @@ add_detected_attribute_1 (cgraph_node *node, const char
*attr, bool *changed)
add_detected_attribute_1 (e->caller, attr, changed);
}
-/* Add attribyte ATTR to function and its aliases. */
+/* Add attribute ATTR to function and its aliases. */
bool
cgraph_node::add_detected_attribute (const char *attr)
@@ -3442,7 +3442,7 @@ cgraph_edge::maybe_hot_p (sreal scale)
if (caller->frequency == NODE_FREQUENCY_HOT)
return true;
- /* Use IPA count and if it s not available appy local heuristics. */
+ /* Use IPA count and if it s not available apply local heuristics. */
if (c.initialized_p ())
{
/* A special case; AFDO zero means that function may quite possibly
diff --git a/gcc/cgraph.h b/gcc/cgraph.h
index 938292cb21a..a7e6ab70b6b 100644
--- a/gcc/cgraph.h
+++ b/gcc/cgraph.h
@@ -219,7 +219,7 @@ public:
void clone_references (symtab_node *node);
/* Remove all stmt references in non-speculative references.
- Those are not maintained during inlining & clonning.
+ Those are not maintained during inlining & cloning.
The exception are speculative references that are updated along
with callgraph edges associated with them. */
void clone_referring (symtab_node *node);
@@ -237,7 +237,7 @@ public:
void remove_stmt_references (gimple *stmt);
/* Remove all stmt references in non-speculative references.
- Those are not maintained during inlining & clonning.
+ Those are not maintained during inlining & cloning.
The exception are speculative references that are updated along
with callgraph edges associated with them. */
void clear_stmts_in_references (void);
@@ -1303,7 +1303,7 @@ struct GTY((tag ("SYMTAB_FUNCTION"))) cgraph_node :
public symtab_node
/* Turn profile to global0. Walk into inlined functions. */
void make_profile_global0 (profile_quality quality);
- /* Scale profile by NUM/DEN. Walk into inlined funtion. */
+ /* Scale profile by NUM/DEN. Walk into inlined function. */
void apply_scale (profile_count num, profile_count den);
/* Scale profile to given IPA_COUNT.
@@ -1962,7 +1962,7 @@ public:
pairs all linked to single statement.
Note that ref may point to different symbol than the corresponding call
- becuase the speculated edge may have been optimized (redirected to
+ because the speculated edge may have been optimized (redirected to
a clone) or inlined.
Given an edge which is part of speculative call, return the first
@@ -2011,7 +2011,7 @@ public:
target2. */
cgraph_edge *speculative_call_for_target (cgraph_node *);
- /* Return REF corresponding to direct call in the specualtive call
+ /* Return REF corresponding to direct call in the speculative call
sequence. */
ipa_ref *speculative_call_target_ref ()
{
diff --git a/gcc/cif-code.def b/gcc/cif-code.def
index 071fd936622..4a032e0d3b3 100644
--- a/gcc/cif-code.def
+++ b/gcc/cif-code.def
@@ -103,7 +103,7 @@ DEFCIFCODE(VARIADIC_THUNK, CIF_FINAL_ERROR,
DEFCIFCODE(ORIGINALLY_INDIRECT_CALL, CIF_FINAL_NORMAL,
N_("originally indirect function call not considered for inlining"))
-/* Ths edge represents an indirect edge with a yet-undetermined callee . */
+/* The edge represents an indirect edge with a yet-undetermined callee . */
DEFCIFCODE(INDIRECT_UNKNOWN_CALL, CIF_FINAL_NORMAL,
N_("indirect function call with a yet undetermined callee"))
diff --git a/gcc/collect2.cc b/gcc/collect2.cc
index 4353be6e3e7..6985e0b4d15 100644
--- a/gcc/collect2.cc
+++ b/gcc/collect2.cc
@@ -1315,9 +1315,9 @@ main (int argc, char **argv)
FILE *stream;
char buf[MAXPATHLEN + 2];
- /* Number of additionnal object files. */
+ /* Number of additional object files. */
int add_nbr = 0;
- /* Maximum of additionnal object files before vector
+ /* Maximum of additional object files before vector
expansion. */
int add_max = 0;
const char *list_filename = arg + 2;
@@ -2803,7 +2803,7 @@ scan_prog_file (const char *prog_name, scanpass
which_pass,
switch (is_ctor_dtor (name))
{
#if TARGET_AIX_VERSION
- /* Add AIX shared library initalisers/finalisers
+ /* Add AIX shared library initialisers/finalisers
to the constructors/destructors list of the
current module. */
case SYM_AIXI:
diff --git a/gcc/combine.cc b/gcc/combine.cc
index b889af43d5c..f97f7b1900d 100644
--- a/gcc/combine.cc
+++ b/gcc/combine.cc
@@ -14453,7 +14453,7 @@ distribute_notes (rtx notes, rtx_insn *from_insn,
rtx_insn *i3, rtx_insn *i2,
/* The landing pad handling needs to be kept in sync with the
prerequisite checking in try_combine. */
int lp_nr = INTVAL (XEXP (note, 0));
- /* A REG_EH_REGION note transfering control can only ever come
+ /* A REG_EH_REGION note transferring control can only ever come
from i3. */
if (lp_nr > 0)
gcc_assert (from_insn == i3);
diff --git a/gcc/configure.ac b/gcc/configure.ac
index 5600a100376..0f3e5605a7f 100644
--- a/gcc/configure.ac
+++ b/gcc/configure.ac
@@ -896,7 +896,7 @@ stk_clash_min=12
stk_clash_max=30
# Keep the default value when the option is not used to 0, this allows us to
-# distinguish between the cases where the user specifially set a value via
+# distinguish between the cases where the user specifically set a value via
# configure and when the normal default value is used.
AC_ARG_WITH(stack-clash-protection-guard-size,
[AS_HELP_STRING([--with-stack-clash-protection-guard-size=size],
@@ -4406,7 +4406,7 @@ elif test x$gcc_cv_ld != x; then
ld_soname_option='-install_name'
;;
# Solaris 2 ld always supports -h. It also supports --soname for GNU
- # ld compatiblity since some Solaris 10 update.
+ # ld compatibility since some Solaris 10 update.
*-*-solaris2*)
gcc_cv_ld_soname=yes
ld_soname_option='-h'
diff --git a/gcc/coretypes.h b/gcc/coretypes.h
index 465bead6863..726299f212e 100644
--- a/gcc/coretypes.h
+++ b/gcc/coretypes.h
@@ -299,12 +299,12 @@ enum pad_direction {
/* No padding is required. */
PAD_NONE,
- /* Insert padding above the data, i.e. at higher memeory addresses
+ /* Insert padding above the data, i.e. at higher memory addresses
when dealing with memory, and at the most significant end when
dealing with registers. */
PAD_UPWARD,
- /* Insert padding below the data, i.e. at lower memeory addresses
+ /* Insert padding below the data, i.e. at lower memory addresses
when dealing with memory, and at the least significant end when
dealing with registers. */
PAD_DOWNWARD
diff --git a/gcc/coroutine-passes.cc b/gcc/coroutine-passes.cc
index fe37854bd32..1b49179c4b9 100644
--- a/gcc/coroutine-passes.cc
+++ b/gcc/coroutine-passes.cc
@@ -267,7 +267,7 @@ make_pass_coroutine_lower_builtins (gcc::context *ctxt)
resume and destroy paths as separate functions if that is found
profitable by the optimisers.
- Once we have remade the connections to their correct postions, we elide
+ Once we have remade the connections to their correct positions, we elide
the labels that the front end inserted. */
static void
diff --git a/gcc/coverage.cc b/gcc/coverage.cc
index 5742dd92166..cbe58033c2d 100644
--- a/gcc/coverage.cc
+++ b/gcc/coverage.cc
@@ -591,7 +591,7 @@ coverage_compute_profile_id (struct cgraph_node *n)
The checksum is calculated carefully so that
source code changes that doesn't affect the control flow graph
won't change the checksum.
- This is to make the profile data useable across source code change.
+ This is to make the profile data usable across source code change.
The downside of this is that the compiler may use potentially
wrong profile data - that the source code change has non-trivial impact
on the validity of profile data (e.g. the reversed condition)
diff --git a/gcc/cselib.cc b/gcc/cselib.cc
index 8a6983f4c69..f7889b4c57a 100644
--- a/gcc/cselib.cc
+++ b/gcc/cselib.cc
@@ -101,7 +101,7 @@ struct cselib_hasher : nofree_ptr_hash <cselib_val>
integers). */
machine_mode mode;
rtx x;
- /* The mode of the contaning MEM, if any, otherwise VOIDmode. */
+ /* The mode of the containing MEM, if any, otherwise VOIDmode. */
machine_mode memmode;
};
typedef key *compare_type;
diff --git a/gcc/ctfc.h b/gcc/ctfc.h
index 289d0e3d55a..0e2315f5b03 100644
--- a/gcc/ctfc.h
+++ b/gcc/ctfc.h
@@ -314,7 +314,7 @@ typedef struct GTY (()) ctf_container
/* CTF string table. */
ctf_strtable_t ctfc_strtable;
- /* Auxilliary string table. At this time, used for keeping func arg names
+ /* Auxiliary string table. At this time, used for keeping func arg names
for BTF. */
ctf_strtable_t ctfc_aux_strtable;
@@ -369,7 +369,7 @@ typedef struct GTY (()) ctf_container
/* Markers for which string table from the CTF container to use. */
#define CTF_STRTAB 0 /* CTF string table. */
-#define CTF_AUX_STRTAB 1 /* CTF auxilliary string table. */
+#define CTF_AUX_STRTAB 1 /* CTF auxiliary string table. */
typedef ctf_container_t * ctf_container_ref;
@@ -389,7 +389,7 @@ extern unsigned int ctfc_get_num_ctf_types
(ctf_container_ref);
extern unsigned int ctfc_get_num_ctf_vars (ctf_container_ref);
-/* Get reference to the CTF string table or the CTF auxilliary
+/* Get reference to the CTF string table or the CTF auxiliary
string table. */
extern ctf_strtable_t * ctfc_get_strtab (ctf_container_ref, int);
diff --git a/gcc/ctfout.cc b/gcc/ctfout.cc
index 15948b51db0..fb8556e33cb 100644
--- a/gcc/ctfout.cc
+++ b/gcc/ctfout.cc
@@ -422,7 +422,7 @@ ctf_asm_sou_lmember (ctf_dmdef_t * dmd)
"ctlm_offsetlo");
}
-/* Asm'out a member of a CTF sruct or union, represented by ctf_member_t. */
+/* Asm'out a member of a CTF struct or union, represented by ctf_member_t. */
static void
ctf_asm_sou_member (ctf_dmdef_t * dmd)
@@ -487,7 +487,7 @@ output_ctf_header (ctf_container_ref ctfc)
funcoff = objtoff + ctfc->ctfc_num_global_objts * sizeof (uint32_t);
/* Object index appears after function info. */
objtidxoff = funcoff + ctfc->ctfc_num_global_funcs * sizeof (uint32_t);
- /* Funxtion index goes next. */
+ /* Function index goes next. */
funcidxoff = objtidxoff + ctfc->ctfc_num_global_objts * sizeof
(uint32_t);
/* Vars appear after function index. */
varoff = funcidxoff + ctfc->ctfc_num_global_funcs * sizeof (uint32_t);
diff --git a/gcc/debug.h b/gcc/debug.h
index 5ffe85af9f9..e5976f25d5a 100644
--- a/gcc/debug.h
+++ b/gcc/debug.h
@@ -268,7 +268,7 @@ dump_go_spec_init (const char *, const struct
gcc_debug_hooks *);
typedef hash_map<const_tree, int> decl_to_instance_map_t;
extern decl_to_instance_map_t *decl_to_instance_map;
-/* Allocate decl_to_instance_map with COUNT slots to begin wtih, if it
+/* Allocate decl_to_instance_map with COUNT slots to begin with, if it
* hasn't been allocated yet. */
inline decl_to_instance_map_t *
diff --git a/gcc/defaults.h b/gcc/defaults.h
index 6364216d968..87f710697f0 100644
--- a/gcc/defaults.h
+++ b/gcc/defaults.h
@@ -956,7 +956,7 @@ see the files COPYING3 and COPYING.RUNTIME respectively.
If not, see
configuration using MD constraint definitions. */
#endif
-/* Determin whether the target runtime library is Bionic */
+/* Determine whether the target runtime library is Bionic */
#ifndef TARGET_HAS_BIONIC
#define TARGET_HAS_BIONIC 0
#endif
diff --git a/gcc/df-problems.cc b/gcc/df-problems.cc
index 710f3c12032..f9769f8a489 100644
--- a/gcc/df-problems.cc
+++ b/gcc/df-problems.cc
@@ -3938,7 +3938,7 @@ df_simulate_fixup_sets (basic_block bb, bitmap live)
i.e. they process the defs before the uses.
df_simulate_initialize_backwards should be called first with a
- bitvector copyied from the DF_LIVE_OUT or DF_LR_OUT. Then
+ bitvector copied from the DF_LIVE_OUT or DF_LR_OUT. Then
df_simulate_one_insn_backwards should be called for each insn in
the block, starting with the last one. Finally,
df_simulate_finalize_backwards can be called to get a new value
@@ -4007,7 +4007,7 @@ df_simulate_finalize_backwards (basic_block bb, bitmap
live)
problems computed before using these functions.
df_simulate_initialize_forwards should be called first with a
- bitvector copyied from the DF_LIVE_IN or DF_LR_IN. Then
+ bitvector copied from the DF_LIVE_IN or DF_LR_IN. Then
df_simulate_one_insn_forwards should be called for each insn in
the block, starting with the first one.
----------------------------------------------------------------------------*/
diff --git a/gcc/diagnostic-context-rich-location.cc
b/gcc/diagnostic-context-rich-location.cc
index 2a88defdf9b..c36e9f97446 100644
--- a/gcc/diagnostic-context-rich-location.cc
+++ b/gcc/diagnostic-context-rich-location.cc
@@ -34,7 +34,7 @@ along with GCC; see the file COPYING3. If not see
#include "simple-diagnostic-path.h"
#include "diagnostic-context-rich-location.h"
-/* Implemenation of the method make_inner_path of the class
+/* Implementation of the method make_inner_path of the class
lazy_diagnostic_context_path. */
std::unique_ptr<diagnostics::paths::path>
@@ -133,7 +133,7 @@ lazy_diagnostic_context_path::make_inner_path () const
gimple *cond_stmt = NULL;
gimple_stmt_iterator gsi = gsi_last_bb (cond_bb);
- /* Currently, we only hanlde GIMPLE_COND.
+ /* Currently, we only handle GIMPLE_COND.
FIXME, will handle GIMPLE_SWITCH and other ctrl stmt later. */
if (gsi_stmt (gsi) && stmt_ends_bb_p (gsi_stmt (gsi)))
if (gimple_code (gsi_stmt (gsi)) == GIMPLE_COND)
diff --git a/gcc/diagnostics/color.cc b/gcc/diagnostics/color.cc
index f639eabbea3..80d80a258b2 100644
--- a/gcc/diagnostics/color.cc
+++ b/gcc/diagnostics/color.cc
@@ -443,7 +443,7 @@ auto_enable_urls ()
/* When logging in a linux over serial line, we see TERM=linux
and no COLORTERM, it is unlikely that the URL escapes will
- work in that environmen either. */
+ work in that environment either. */
if (!colorterm && term && !strcmp (term, "linux"))
return false;
diff --git a/gcc/diagnostics/context.h b/gcc/diagnostics/context.h
index ad1192e93a3..44ec55820f6 100644
--- a/gcc/diagnostics/context.h
+++ b/gcc/diagnostics/context.h
@@ -226,7 +226,7 @@ private:
- reporting those diagnostics to zero or more output sinks
(e.g. text vs SARIF)
- providing a "dump" member function for a debug dump of the state of
- the diagnostics subsytem
+ the diagnostics subsystem
- direct vs buffered diagnostics (see class diagnostics::buffer)
- tracking the original argv of the program (for SARIF output)
- crash-handling
diff --git a/gcc/diagnostics/sarif-sink.cc b/gcc/diagnostics/sarif-sink.cc
index f601dbe7c5f..d56802c957f 100644
--- a/gcc/diagnostics/sarif-sink.cc
+++ b/gcc/diagnostics/sarif-sink.cc
@@ -5175,7 +5175,7 @@ get_message_from_result (const sarif_result &result)
}
/* Assuming that a single diagnostic has been emitted to
- DC, get a json::object for the messsage object within
+ DC, get a json::object for the message object within
the result. */
static const json::object *
diff --git a/gcc/double-int.cc b/gcc/double-int.cc
index a74de605884..189fc5ea79d 100644
--- a/gcc/double-int.cc
+++ b/gcc/double-int.cc
@@ -1246,7 +1246,7 @@ double_int::lrotate (HOST_WIDE_INT count, unsigned int
prec) const
return t1 | t2;
}
-/* Rotate A rigth by COUNT places keeping only PREC bits of result.
+/* Rotate A right by COUNT places keeping only PREC bits of result.
Rotate right if COUNT is negative. */
double_int
diff --git a/gcc/dwarf2asm.cc b/gcc/dwarf2asm.cc
index bfd05e6be25..54d008a02be 100644
--- a/gcc/dwarf2asm.cc
+++ b/gcc/dwarf2asm.cc
@@ -874,7 +874,7 @@ dw2_asm_output_delta_uleb128 (const char *lab1
ATTRIBUTE_UNUSED,
putc ('-', asm_out_file);
/* dwarf2out.cc might give us a label expression (e.g. .LVL548-1)
as second argument. If so, make it a subexpression, to make
- sure the substraction is done in the right order. */
+ sure the subtraction is done in the right order. */
if (strchr (lab2, '-') != NULL)
{
putc ('(', asm_out_file);
diff --git a/gcc/dwarf2cfi.cc b/gcc/dwarf2cfi.cc
index f2ffaa8ad38..a7c00354ff1 100644
--- a/gcc/dwarf2cfi.cc
+++ b/gcc/dwarf2cfi.cc
@@ -2076,7 +2076,7 @@ dwarf2out_frame_debug_expr (rtx expr)
/* Rule 18: If stack is aligned, we will use FP as a
reference to represent the address of the stored
- regiser. */
+ register. */
if (fde
&& fde->stack_realign
&& REG_P (src)
diff --git a/gcc/dwarf2ctf.cc b/gcc/dwarf2ctf.cc
index a561087b047..d13bb424f87 100644
--- a/gcc/dwarf2ctf.cc
+++ b/gcc/dwarf2ctf.cc
@@ -118,7 +118,7 @@ ctf_get_AT_data_member_location (dw_die_ref die)
else if (attr)
field_location = AT_unsigned (attr) * 8;
- /* Otherwise the location is non-existant, e.g. for union members. */
+ /* Otherwise the location is non-existent, e.g. for union members. */
}
return field_location;
@@ -908,14 +908,14 @@ handle_ctf_type_tags (ctf_container_ref ctfc, dw_die_ref
annot_die,
/* Handle any DW_AT_GNU_annotation on decl DIE by constructing a CTF_K_DECL_TAG
type for the DW_TAG_GNU_annotation DIE to which it points, if this has not
been previously constructed. There may be multiple annotations chained
- together by further occurances of DW_AT_GNU_annotation in the annoation DIEs
+ together by further occurrences of DW_AT_GNU_annotation in the annotation
DIEs
themselves, in which case a corresponding CTF_K_DECL_TAG type is created for
each. Unlike TYPE_TAGs, which form a chain, each DECL_TAG individually
refers directly to the annotated decl, which should be supplied in REF_DTD.
IDX is the zero-based component index indicating to which function parameter
or struct or union member the DECL_TAG refers, or (uint32_t) -1 if it refers
to a function decl or sou itself.
- Note that because individual DECL_TAGs refer direcly to the annotated decl,
+ Note that because individual DECL_TAGs refer directly to the annotated decl,
they cannot be deduplicated across usages. */
static void
diff --git a/gcc/dwarf2out.cc b/gcc/dwarf2out.cc
index bf342e468bf..f14885ea1f7 100644
--- a/gcc/dwarf2out.cc
+++ b/gcc/dwarf2out.cc
@@ -18321,7 +18321,7 @@ cst_pool_loc_descr (tree loc)
if (!TREE_ASM_WRITTEN (SYMBOL_REF_DECL (XEXP (rtl, 0))))
{
expansion_failed (loc, NULL_RTX,
- "CST value in contant pool but not marked.");
+ "CST value in constant pool but not marked.");
return 0;
}
return mem_loc_descriptor (XEXP (rtl, 0), get_address_mode (rtl),
@@ -18356,7 +18356,7 @@ loc_list_for_address_of_addr_expr_of_indirect_ref (tree
loc, bool toplev,
if (!INDIRECT_REF_P (obj))
{
expansion_failed (obj,
- NULL_RTX, "no indirect ref in inner refrence");
+ NULL_RTX, "no indirect ref in inner reference");
return 0;
}
if (!offset && known_eq (bitpos, 0))
@@ -18609,7 +18609,7 @@ resolve_args_picking_1 (dw_loc_descr_ref loc, unsigned
initial_frame_offset,
one stack slot per argument (0 for the first one, 1 for the second
one, etc.).
- The targetted argument number (N) is already set as the operand,
+ The targeted argument number (N) is already set as the operand,
and the number of temporaries can be computed with:
frame_offsets_ - dpi->args_count */
off += frame_offset_ - dpi->args_count;
@@ -19029,7 +19029,7 @@ typed_binop_from_tree (enum dwarf_location_atom op,
tree loc,
/* Generate Dwarf location list representing LOC.
If WANT_ADDRESS is false, expression computing LOC will be computed
If WANT_ADDRESS is 1, expression computing address of LOC will be returned
- if WANT_ADDRESS is 2, expression computing address useable in location
+ if WANT_ADDRESS is 2, expression computing address usable in location
will be returned (i.e. DW_OP_reg can be used
to refer to register values).
@@ -22912,7 +22912,7 @@ gen_array_type_die (tree type, dw_die_ref context_die)
there is no difference between an array of arrays and a multidimensional
array. We don't do this for Ada to remain as close as possible to the
actual representation, which is especially important against the language
- flexibilty wrt arrays of variable size. */
+ flexibility wrt arrays of variable size. */
bool collapse_nested_arrays = !is_ada ();
diff --git a/gcc/dwarf2out.h b/gcc/dwarf2out.h
index aa806460c6e..312dbb38252 100644
--- a/gcc/dwarf2out.h
+++ b/gcc/dwarf2out.h
@@ -288,7 +288,7 @@ struct GTY(()) dw_val_node {
from DW_OP_addr with a dtp-relative symbol relocation. */
unsigned int dw_loc_dtprel_v : 1;
/* For DW_OP_pick, DW_OP_dup and DW_OP_over operations: true iff.
- it targets a DWARF prodecure argument. In this case, it needs to
be
+ it targets a DWARF procedure argument. In this case, it needs to
be
relocated according to the current frame offset. */
unsigned int dw_loc_frame_offset_rel_v : 1;
} u1;
@@ -345,7 +345,7 @@ struct GTY((chain_next ("%h.dw_loc_next")))
dw_loc_descr_node {
from DW_OP_addr with a dtp-relative symbol relocation. */
#define dw_loc_dtprel dw_loc_oprnd1.u.u1.dw_loc_dtprel_v
/* For DW_OP_pick, DW_OP_dup and DW_OP_over operations: true iff.
- it targets a DWARF prodecure argument. In this case, it needs to be
+ it targets a DWARF procedure argument. In this case, it needs to be
relocated according to the current frame offset. */
#define dw_loc_frame_offset_rel dw_loc_oprnd1.u.u1.dw_loc_frame_offset_rel_v
#define dw_loc_addr dw_loc_oprnd2.u.u2
diff --git a/gcc/btfout.cc b/gcc/btfout.cc
index 06c96816e32..2ba69b0c678 100644
--- a/gcc/btfout.cc
+++ b/gcc/btfout.cc
@@ -51,7 +51,7 @@ static GTY (()) section * btf_info_section;
#define BTF_INFO_SECTION_FLAGS (SECTION_DEBUG)
-/* Maximum size (in bytes) for an artifically generated BTF label. */
+/* Maximum size (in bytes) for an artificially generated BTF label. */
#define MAX_BTF_LABEL_BYTES 40
@@ -409,7 +409,7 @@ btf_asm_type (ctf_dtdef_ref dtd)
if (dtd->dtd_data.ctti_type == CTF_K_UNION)
btf_kflag = 1;
- /* PR debug/111735. Encode foward-declared enums as BTF_KIND_ENUM
+ /* PR debug/111735. Encode forward-declared enums as BTF_KIND_ENUM
with vlen=0. A representation for these is not formally defined;
this is the de-facto standard used by other tools like clang
and pahole. */
@@ -691,7 +691,7 @@ output_btf_vars (ctf_container_ref ctfc)
}
/* Output BTF string records. The BTF strings section is a concatenation
- of the standard and auxilliary string tables in the ctf container. */
+ of the standard and auxiliary string tables in the ctf container. */
static void
output_btf_strs (ctf_container_ref ctfc)
@@ -1204,7 +1204,7 @@ btf_add_used_type_1 (ctf_container_ref ctfc,
ctf_dtdef_ref dtd,
farg->farg_type = btf_add_used_type_1 (ctfc, farg->farg_type,
false, false,
create_fixups);
/* Note: argument names are stored in the auxilliary string table,
since CTF does not include arg names. That table has not been
cleared, so no need to re-add argument names here. */
}
@@ -1204,7 +1204,7 @@ btf_add_used_type_1 (ctf_container_ref ctfc,
false, false,
create_fixups);
- /* Note: argument names are stored in the auxilliary string table,
+ /* Note: argument names are stored in the auxiliary string table,
since CTF does not include arg names. That table has not been
cleared, so no need to re-add argument names here. */
diff --git a/gcc/cse.cc b/gcc/cse.cc
index b4b39e3ebf8..c1e0cc2167c 100644
--- a/gcc/cse.cc
+++ b/gcc/cse.cc
@@ -4163,7 +4163,7 @@ struct set
/* Nonzero if the SET_SRC contains something
whose value cannot be predicted and understood. */
unsigned int src_volatile : 1;
/* Nonzero if RTL is an artifical set that has been created to describe
part of an insn's effect. Zero means that RTL appears directly in
the insn pattern. */
unsigned int is_fake_set : 1;
@@ -4262,7 +4262,7 @@ try_back_substitute_reg (rtx set, rtx_insn *insn)
}
/* Add an entry containing RTL X into SETS. IS_FAKE_SET is true if X is
- an artifical set that has been created to describe part of an insn's
+ an artificial set that has been created to describe part of an insn's
effect. */
static inline void
add_to_set (vec<struct set> *sets, rtx x, bool is_fake_set)
@@ -7046,7 +7046,7 @@ count_stores (rtx x, const_rtx set ATTRIBUTE_UNUSED, void
*data)
/* Return if DEBUG_INSN pattern PAT needs to be reset because some dead
pseudo doesn't have a replacement. COUNTS[X] is zero if register X
- is dead and REPLACEMENTS[X] is null if it has no replacemenet.
+ is dead and REPLACEMENTS[X] is null if it has no replacement.
Set *SEEN_REPL to true if we see a dead register that does have
a replacement. */
@@ -4163,7 +4163,7 @@ struct set
whose value cannot be predicted and understood. */
unsigned int src_volatile : 1;
- /* Nonzero if RTL is an artifical set that has been created to describe
+ /* Nonzero if RTL is an artificial set that has been created to describe
part of an insn's effect. Zero means that RTL appears directly in
the insn pattern. */
diff --git a/gcc/ctfc.cc b/gcc/ctfc.cc
index 8beca20df8c..c681c97cc3f 100644
--- a/gcc/ctfc.cc
+++ b/gcc/ctfc.cc
@@ -58,7 +58,7 @@ unsigned int ctfc_get_num_ctf_vars (ctf_container_ref ctfc)
return ctfc->ctfc_vars->elements ();
}
/* Get reference to the CTF string table or the CTF auxilliary
string table. */
ctf_strtable_t *
@@ -321,7 +321,7 @@ const char *
ctf_add_string (ctf_container_ref ctfc, const char * name,
uint32_t * name_offset, int aux_str = CTF_STRTAB)
{
/* Get the CTF string table or the CTF auxilliary string table,
as applicable. */
ctf_strtable_t *str_table = ctfc_get_strtab (ctfc, aux_str);
return ctfc_strtable_add_str (str_table, name, name_offset);
@@ -816,8 +816,8 @@ ctf_add_function_arg (ctf_container_ref ctfc, dw_die_ref
func,
farg = ggc_cleared_alloc<ctf_func_arg_t> ();
- /* Buffer the strings in the auxilliary string table. CTF V3 format does not
- require function argument names. Use auxilliary string table to keep
+ /* Buffer the strings in the auxiliary string table. CTF V3 format does not
+ require function argument names. Use auxiliary string table to keep
these strings to avoid unnecessary bloat in CTF section in CTF V3. */
farg->farg_name = ctf_add_string (ctfc, name, &(farg->farg_name_offset),
CTF_AUX_STRTAB);
@@ -58,7 +58,7 @@ unsigned int ctfc_get_num_ctf_vars (ctf_container_ref ctfc)
return ctfc->ctfc_vars->elements ();
}
-/* Get reference to the CTF string table or the CTF auxilliary
+/* Get reference to the CTF string table or the CTF auxiliary
string table. */
ctf_strtable_t *
@@ -321,7 +321,7 @@ const char *
uint32_t * name_offset, int aux_str = CTF_STRTAB)
{
- /* Get the CTF string table or the CTF auxilliary string table,
+ /* Get the CTF string table or the CTF auxiliary string table,
as applicable. */
ctf_strtable_t *str_table = ctfc_get_strtab (ctfc, aux_str);
--
2.43.0